@@ -26,10 +26,10 @@
 #include <kapp.h>
 
 
-class KVILIB_API KviTalApplication : public KApplication
+class KVILIB_API KviTalApplication : public TDEApplication
 {
 	Q_OBJECT
-  TQ_OBJECT
+  
 public:
 	KviTalApplication(int &argc,char ** argv);
 	~KviTalApplication();
