@@ -25,7 +25,7 @@
 
 #include "kvi_tal_menubar.h"
 
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_TDE_SUPPORT
 
 	KviTalMenuBar::KviTalMenuBar(TQWidget * par,const char * nam)
 	: KMenuBar(par,nam)
