@@ -50,8 +50,8 @@
 	#include <stdlib.h> // for getenv()
 	#include <unistd.h> // for symlink() <-- unused ?
 	
-	#ifdef COMPILE_KDE_SUPPORT
-		#include <kconfig.h>
+	#ifdef COMPILE_TDE_SUPPORT
+		#include <tdeconfig.h>
 		#include <kstddirs.h>
 	#endif
 
@@ -547,20 +547,20 @@ void KviApp::findGlobalKvircDirectory()
 #else // !COMPILE_ON_WINDOWS
 
 	// Since I had many problems with it
-	// because of strange distributions or KDEDIRS
+	// because of strange distributions or TDEDIRS
 	// I do it in that way...
-	#ifdef COMPILE_KDE_SUPPORT
+	#ifdef COMPILE_TDE_SUPPORT
 		// KDE compilation ...
-		// The things usually go installed into $KDEDIR/share/apps/kvirc/$KVI_VERSION_BRANCH
+		// The things usually go installed into $TDEDIR/share/apps/kvirc/$KVI_VERSION_BRANCH
 		// Look in the main KDE directory
-		KStandardDirs * d = dirs();
+		TDEStandardDirs * d = dirs();
 		if(d)
 		{
 			m_szGlobalKvircDir = locate("appdata","");
 			if(checkGlobalKvircDirectory(m_szGlobalKvircDir))return;
 			#ifdef HAVE_GETENV
-				//KDEDIR sanity check...
-				m_szGlobalKvircDir = getenv("KDEDIR");
+				//TDEDIR sanity check...
+				m_szGlobalKvircDir = getenv("TDEDIR");
 				m_szGlobalKvircDir+="/share/apps/kvirc/" KVI_VERSION_BRANCH;
 				if(checkGlobalKvircDirectory(m_szGlobalKvircDir))return;
 			#endif
@@ -568,7 +568,7 @@ void KviApp::findGlobalKvircDirectory()
 		// FAILED ? Check the usual way...
 	#endif //COMPILE_WITH_KDE
 
-	// Non KDE compilation , or not found under $KDEDIR/share/apps/kvirc/$KVI_VERSION_BRANCH
+	// Non KDE compilation , or not found under $TDEDIR/share/apps/kvirc/$KVI_VERSION_BRANCH
 
 	// Check for MacOS X Bundle compilation
 	#ifdef Q_OS_MACX
@@ -596,7 +596,7 @@ void KviApp::findGlobalKvircDirectory()
 		if(checkGlobalKvircDirectory(m_szGlobalKvircDir))return;
 	}
 
-	#ifdef COMPILE_KDE_SUPPORT
+	#ifdef COMPILE_TDE_SUPPORT
 		for(int k=0;usualKvircGlobalDir[k] != 0;k++){
 			m_szGlobalKvircDir = TQDir::homeDirPath();
 			m_szGlobalKvircDir+= "/.trinity";
@@ -604,7 +604,7 @@ void KviApp::findGlobalKvircDirectory()
 			m_szGlobalKvircDir+= KVI_VERSION_BRANCH;
 			if(checkGlobalKvircDirectory(m_szGlobalKvircDir))return;
 		}
-	#endif //COMPILE_KDE_SUPPORT
+	#endif //COMPILE_TDE_SUPPORT
 
 	m_szGlobalKvircDir="";
 
@@ -612,12 +612,12 @@ void KviApp::findGlobalKvircDirectory()
 	// THE TRANSLATION DIRECTORY WAS NOT FOUND YET
 	// AND THE LOCALE IS NOT INITIALIZED AT ALL
 
-	#ifdef COMPILE_KDE_SUPPORT
+	#ifdef COMPILE_TDE_SUPPORT
 		KviMessageBox::warning("Unable to find the shared Kvirc directory.\n"\
-				"The usual path for this directory is $KDEDIR/share/apps/kvirc.\n"\
+				"The usual path for this directory is $TDEDIR/share/apps/kvirc.\n"\
 				"Are you sure that 'make install' worked correctly ?\n"\
 				"Please make sure that you have the read permission to that directory\n"\
-				"and you have set KDEDIR correctly. You may also try to rerun 'make install'.\n"\
+				"and you have set TDEDIR correctly. You may also try to rerun 'make install'.\n"\
 				"A detailed explaination of the Kvirc directory system is in the INSTALL document\n"\
 				"shipped with the kvirc source dirstribution.\n"\
 				"Trying to run anyway...");
@@ -627,7 +627,7 @@ void KviApp::findGlobalKvircDirectory()
 				"Something went wrong during the bundle creation.\n"\
 				"Please read the documentation and make sure to set proper paths for --prefix, -bindir, -libdir and --datadir during the configure run.\n"\
 				"Trying to run anyway...\n");
-	#else //!defined(COMPILE_KDE_SUPPORT) && !defined(Q_OS_MACX)
+	#else //!defined(COMPILE_TDE_SUPPORT) && !defined(Q_OS_MACX)
 		KviMessageBox::warning("Unable to find the shared Kvirc directory.\n"\
 				"The usual path for this directory is /usr/local/share/kvirc.\n"\
 				"Are you sure that 'make install' worked correctly ?\n"\
@@ -645,13 +645,13 @@ bool KviApp::findLocalKvircDirectory()
 {
 	// Here we check if we already did the setup
 	// and we have the kvirc local directory saved somewhere
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_TDE_SUPPORT
 	if(m_szConfigFile.isEmpty())
 	{  // don't do that if user supplied a config file :)
-		KConfig * cfg = config();
+		TDEConfig * cfg = config();
 		if(cfg)
 		{
-			if(cfg->getConfigState() == KConfig::ReadWrite)
+			if(cfg->getConfigState() == TDEConfig::ReadWrite)
 			{
 				cfg->setGroup("Main");
 				m_szLocalKvircDir = cfg->readEntry("LocalKvircDirectory","");
@@ -665,7 +665,7 @@ bool KviApp::findLocalKvircDirectory()
 			}
 		}
 	}
-#endif //COMPILE_KDE_SUPPORT
+#endif //COMPILE_TDE_SUPPORT
 
 #ifdef COMPILE_ON_WINDOWS
 	if(KviFileUtils::fileExists(g_pApp->applicationDirPath()+KVI_PATH_SEPARATOR_CHAR+"portable")) {
@@ -820,14 +820,14 @@ void KviApp::saveKvircDirectory()
 #else //!COMPILE_ON_WINDOWS
 */
 	// Here we save the local directory path
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_TDE_SUPPORT
 	// In KDE we use the application config file
 	if(m_szConfigFile.isEmpty())
 	{	// not if user supplied a config file
-		KConfig * cfg = config();
+		TDEConfig * cfg = config();
 		if(cfg)
 		{
-			if(cfg->getConfigState() == KConfig::ReadWrite)
+			if(cfg->getConfigState() == TDEConfig::ReadWrite)
 			{
 				cfg->setGroup("Main");
 				cfg->writeEntry("LocalKvircDirectory",m_szLocalKvircDir);
@@ -837,7 +837,7 @@ void KviApp::saveKvircDirectory()
 			}
 		}
 	}
-#endif //COMPILE_KDE_SUPPORT
+#endif //COMPILE_TDE_SUPPORT
 	// In NON-KDE we use $HOME/.kvirc.rc or $HOME/kvirc.ini
 
 	TQString szF = TQDir::homeDirPath();
