@@ -51,7 +51,7 @@
 		#include <tqx11info_x11.h>
 		#define get_xdisplay QX11Info::display
 	#else
-		#define get_xdisplay qt_xdisplay
+		#define get_xdisplay tqt_xdisplay
 	#endif
 
 #endif
