@@ -146,7 +146,7 @@ KviWindow::KviWindow(int type,KviFrame * lpFrm,const TQString &name,KviConsole *
 	setMinimumSize(KVI_WINDOW_MIN_WIDTH,KVI_WINDOW_MIN_HEIGHT);
 #ifdef COMPILE_USE_QT4
 	//setAutoFillBackground(false);
-	setFocusPolicy(TTQ_StrongFocus);
+	setFocusPolicy(TQ_StrongFocus);
 #else
 	setBackgroundMode(NoBackground);
 	setFocusPolicy(TQ_StrongFocus);
@@ -289,7 +289,7 @@ bool KviWindow::focusNextPrevChild(bool next)
 	if(w)
 	{
 #ifdef COMPILE_USE_QT4
-		if(w->focusPolicy() == TTQ_StrongFocus)return false;
+		if(w->focusPolicy() == TQ_StrongFocus)return false;
 #else
 		if(w->focusPolicy() == TQ_StrongFocus)return false;
 #endif
@@ -1066,8 +1066,8 @@ bool KviWindow::eventFilter(TQObject *o,TQEvent *e)
 		break;
 	case TQEvent::MouseButtonPress:
 #ifdef COMPILE_USE_QT4
-		if( (((TQWidget *)o)->focusPolicy() == TTQ_NoFocus) ||
-		        (((TQWidget *)o)->focusPolicy() == TTQ_TabFocus))
+		if( (((TQWidget *)o)->focusPolicy() == TQ_NoFocus) ||
+		        (((TQWidget *)o)->focusPolicy() == TQ_TabFocus))
 #else
 		if( (((TQWidget *)o)->focusPolicy() == TQ_NoFocus) ||
 		        (((TQWidget *)o)->focusPolicy() == TQ_TabFocus))
@@ -1114,7 +1114,7 @@ void KviWindow::childInserted(TQWidget * o)
 	else
 	{
 #ifdef COMPILE_USE_QT4
-		if(!m_pFocusHandler && (o->focusPolicy() == TTQ_StrongFocus))
+		if(!m_pFocusHandler && (o->focusPolicy() == TQ_StrongFocus))
 #else
 		if(!m_pFocusHandler && (o->focusPolicy() == TQ_StrongFocus))
 #endif
